--------------------------------------------------
---  Copyright 2008-2010, HDRsoft - www.hdrsoft.com   
--------------------------------------------------

local LrApplication = import 'LrApplication'
local LrDialogs = import 'LrDialogs'
local LrErrors = import 'LrErrors'
local LrFileUtils = import 'LrFileUtils'
local LrPathUtils = import 'LrPathUtils'
local LrExportSession = import 'LrExportSession'
local LrTasks = import 'LrTasks'
local prefs = import 'LrPrefs'.prefsForPlugin() 
local LrLogger = import 'LrLogger'

local myLogger = LrLogger('PhotomatixLogger')
myLogger:enable("print") 

ExportToPhotomatix = {}

function ExportToPhotomatix.outputToLog(message)
	myLogger:trace(message)
end

-- ExportToPhotomatix.outputToLog("Passe dans ExportToPhotomatix")


LrTasks.startAsyncTask( function()

	ExportToPhotomatix.outputToLog(string.format('startAsyncTask prefs.photomatix4Path: %s',prefs.photomatix4Path))

	require 'PhotomatixApp'

	local appPath=prefs.photomatix4Path
	local pathExist=false
	if appPath then
		pathExist=LrFileUtils.exists(appPath) 
		pathExist=PhotomatixApp.clientExists(appPath, true)
	end 
	
	if not pathExist  then
		PhotomatixApp.getPath()
	end
	
	appPath=prefs.photomatix4Path
	if not LrFileUtils.exists(appPath) then
		LrErrors.throwUserError("Could not find Photomatix Pro application compatible with this plug-in") 		
		return
	end
		

	
	LrTasks.startAsyncTask( function()
		local activeCatalog = LrApplication.activeCatalog()
		local filmstrip = activeCatalog.targetPhotos	
		local exportSession = LrExportSession{
			exportSettings = {
				LR_exportServiceProvider = 'com.hdrsoft.photomatix.export.lightroom',
				LR_exportServiceProviderTitle = "Photomatix",
				LR_format="TIFF",
				LR_tiff_compressionMethod="compressionMethod_None",
				LR_export_bitDepth=16,
				LR_export_colorSpace="AdobeRGB",
				LR_minimizeEmbeddedMetadata = false,		
				LR_size_resolution=300,
				LR_metadata_keywordOptions="lightroomHierarchical",
				LR_minimizeEmbeddedMetadata = false,
				LR_removeLocationMetadata,
			},
		photosToExport = filmstrip }	
		exportSession:doExportOnCurrentTask()
	end )
end )


